pub enum Error {
Io(ErrorKind),
Other,
}Expand description
Error type used by the shell and returned by command handlers.
Transport errors are wrapped into Error::Io so that every command
handler can use the same concrete error type regardless of the underlying
transport.
Variants
Io(ErrorKind)
An I/O error occurred on the underlying transport.
Other
An operation failed for another reason.
Implementations